==> org.eclipse.gemoc.dsl.ui.source_3.0.0.202006160837.jar: org/eclipse/gemoc/ui/highlighting/DslHighlightingConfiguration.java <==
package org.eclipse.gemoc.ui.highlighting;

import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.RGB;
import org.eclipse.xtext.ui.editor.syntaxcoloring.DefaultHighlightingConfiguration;
import org.eclipse.xtext.ui.editor.syntaxcoloring.IHighlightingConfigurationAcceptor;
import org.eclipse.xtext.ui.editor.utils.TextStyle;

@SuppressWarnings("all")
public class DslHighlightingConfiguration extends DefaultHighlightingConfiguration {
  public final static String KEY_ID = "dsl_key";
  
  public final static String KEY_PLUGIN_ID = "plugin_key";
  
  public final static String OPTIONAL_KEY_PLUGIN_ID = "optional_plugin_key";
  
  public final static String VALUE_ID = "dsl_value";
  
  public final static String SEPARATOR_ID = "dsl_separator";
  
  public final static String LINESEPARATOR_ID = "dsl_lineseparator";
  
  @Override
  public void configure(final IHighlightingConfigurationAcceptor acceptor) {
    super.configure(acceptor);
    acceptor.acceptDefaultHighlighting(DslHighlightingConfiguration.KEY_ID, "Entry key", this.keyTextStyle());
    acceptor.acceptDefaultHighlighting(DslHighlightingConfiguration.KEY_PLUGIN_ID, "Plugin entry key", this.pluginKeyTextStyle());
    acceptor.acceptDefaultHighlighting(DslHighlightingConfiguration.OPTIONAL_KEY_PLUGIN_ID, "Optional entry key", this.pluginOptionalKeyTextStyle());
    acceptor.acceptDefaultHighlighting(DslHighlightingConfiguration.VALUE_ID, "Entry value", this.valueTextStyle());
    acceptor.acceptDefaultHighlighting(DslHighlightingConfiguration.SEPARATOR_ID, "Entry separator", this.separatorTextStyle());
    acceptor.acceptDefaultHighlighting(DslHighlightingConfiguration.LINESEPARATOR_ID, "Line separator", this.lineSeparatorTextStyle());
  }
  
  public TextStyle keyTextStyle() {
    final TextStyle textStyle = this.defaultTextStyle().copy();
    RGB _rGB = new RGB(0, 26, 171);
    textStyle.setColor(_rGB);
    return textStyle;
  }
  
  public TextStyle pluginKeyTextStyle() {
    final TextStyle textStyle = this.defaultTextStyle().copy();
    RGB _rGB = new RGB(145, 85, 0);
    textStyle.setColor(_rGB);
    return textStyle;
  }
  
  public TextStyle pluginOptionalKeyTextStyle() {
    final TextStyle textStyle = this.defaultTextStyle().copy();
    RGB _rGB = new RGB(145, 85, 0);
    textStyle.setColor(_rGB);
    textStyle.setStyle(SWT.ITALIC);
    return textStyle;
  }
  
  public TextStyle valueTextStyle() {
    final TextStyle textStyle = this.defaultTextStyle().copy();
    textStyle.setStyle(SWT.ITALIC);
    return textStyle;
  }
  
  public TextStyle separatorTextStyle() {
    final TextStyle textStyle = this.defaultTextStyle().copy();
    return textStyle;
  }
  
  public TextStyle lineSeparatorTextStyle() {
    final TextStyle textStyle = this.numberTextStyle().copy();
    textStyle.setStyle(SWT.NORMAL);
    return textStyle;
  }
}

==> org.eclipse.gemoc.dsl.ui.source_3.3.0.202206300952.jar: org/eclipse/gemoc/ui/highlighting/DslHighlightingConfiguration.java <==
package org.eclipse.gemoc.ui.highlighting;

import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.RGB;
import org.eclipse.xtext.ui.editor.syntaxcoloring.DefaultHighlightingConfiguration;
import org.eclipse.xtext.ui.editor.syntaxcoloring.IHighlightingConfigurationAcceptor;
import org.eclipse.xtext.ui.editor.utils.TextStyle;

@SuppressWarnings("all")
public class DslHighlightingConfiguration extends DefaultHighlightingConfiguration {
  public static final String KEY_ID = "dsl_key";
  
  public static final String KEY_PLUGIN_ID = "plugin_key";
  
  public static final String OPTIONAL_KEY_PLUGIN_ID = "optional_plugin_key";
  
  public static final String VALUE_ID = "dsl_value";
  
  public static final String SEPARATOR_ID = "dsl_separator";
  
  public static final String LINESEPARATOR_ID = "dsl_lineseparator";
  
  @Override
  public void configure(final IHighlightingConfigurationAcceptor acceptor) {
    super.configure(acceptor);
    acceptor.acceptDefaultHighlighting(DslHighlightingConfiguration.KEY_ID, "Entry key", this.keyTextStyle());
    acceptor.acceptDefaultHighlighting(DslHighlightingConfiguration.KEY_PLUGIN_ID, "Plugin entry key", this.pluginKeyTextStyle());
    acceptor.acceptDefaultHighlighting(DslHighlightingConfiguration.OPTIONAL_KEY_PLUGIN_ID, "Optional entry key", this.pluginOptionalKeyTextStyle());
    acceptor.acceptDefaultHighlighting(DslHighlightingConfiguration.VALUE_ID, "Entry value", this.valueTextStyle());
    acceptor.acceptDefaultHighlighting(DslHighlightingConfiguration.SEPARATOR_ID, "Entry separator", this.separatorTextStyle());
    acceptor.acceptDefaultHighlighting(DslHighlightingConfiguration.LINESEPARATOR_ID, "Line separator", this.lineSeparatorTextStyle());
  }
  
  public TextStyle keyTextStyle() {
    final TextStyle textStyle = this.defaultTextStyle().copy();
    RGB _rGB = new RGB(0, 26, 171);
    textStyle.setColor(_rGB);
    return textStyle;
  }
  
  public TextStyle pluginKeyTextStyle() {
    final TextStyle textStyle = this.defaultTextStyle().copy();
    RGB _rGB = new RGB(145, 85, 0);
    textStyle.setColor(_rGB);
    return textStyle;
  }
  
  public TextStyle pluginOptionalKeyTextStyle() {
    final TextStyle textStyle = this.defaultTextStyle().copy();
    RGB _rGB = new RGB(145, 85, 0);
    textStyle.setColor(_rGB);
    textStyle.setStyle(SWT.ITALIC);
    return textStyle;
  }
  
  public TextStyle valueTextStyle() {
    final TextStyle textStyle = this.defaultTextStyle().copy();
    textStyle.setStyle(SWT.ITALIC);
    return textStyle;
  }
  
  public TextStyle separatorTextStyle() {
    final TextStyle textStyle = this.defaultTextStyle().copy();
    return textStyle;
  }
  
  public TextStyle lineSeparatorTextStyle() {
    final TextStyle textStyle = this.numberTextStyle().copy();
    textStyle.setStyle(SWT.NORMAL);
    return textStyle;
  }
}
